# PROCESSADOR DE IMAGEM VIRTUAL
### VIRTUAL IMAGE PROCESSOR 

**PORTUGUES**
Descricao.
O processamento da imagem do pacote e usado para:
	Em processamento:
		- Correspondência de histograma
		- Semelhanca estrutural
		- Redimensionar imagem
	Util:
		- Ler imagem
		- Salvar imagem
		- Plotar imagem
		- Resultado da trama
		- Plotar histograma

**ENGLISH**
Description.
The package image processing is used to:
	Processing:
		- Histogram  matching
		- Structural similarity
		- Resize image
	Utils: 
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram

## Installation
**PORTUGUES**
Usar o gerenciador de pacotes [pip](https://pip.pypa.io/en/stable/) para instalar processador_imagem

**ENGLISH**
Use the package manager [pip](https://pip.pypa.io/en/stable/) to install processador_imagem

```bash
pip install processador_imagem_virtual
```

## Author
Ubiratan Motta

## License
[MIT](https://choosealicense.com/licenses/mit/)